==> kubernetes-model-core-5.8.1-sources.jar: io/fabric8/kubernetes/api/model/LabelSelectorFluent.java <==
package io.fabric8.kubernetes.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import com.fasterxml.jackson.annotation.JsonInclude;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface LabelSelectorFluent<A extends io.fabric8.kubernetes.api.model.LabelSelectorFluent<A>> extends io.fabric8.kubernetes.api.builder.Fluent<A>{
  public A addToMatchExpressions(java.lang.Integer index,io.fabric8.kubernetes.api.model.LabelSelectorRequirement item);
  public A setToMatchExpressions(java.lang.Integer index,io.fabric8.kubernetes.api.model.LabelSelectorRequirement item);
  public A addToMatchExpressions(io.fabric8.kubernetes.api.model.LabelSelectorRequirement... items);
  public A addAllToMatchExpressions(java.util.Collection<io.fabric8.kubernetes.api.model.LabelSelectorRequirement> items);
  public A removeFromMatchExpressions(io.fabric8.kubernetes.api.model.LabelSelectorRequirement... items);
  public A removeAllFromMatchExpressions(java.util.Collection<io.fabric8.kubernetes.api.model.LabelSelectorRequirement> items);
  public A removeMatchingFromMatchExpressions(java.util.function.Predicate<io.fabric8.kubernetes.api.model.LabelSelectorRequirementBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildMatchExpressions instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public java.util.List<io.fabric8.kubernetes.api.model.LabelSelectorRequirement> getMatchExpressions();
  public java.util.List<io.fabric8.kubernetes.api.model.LabelSelectorRequirement> buildMatchExpressions();
  public io.fabric8.kubernetes.api.model.LabelSelectorRequirement buildMatchExpression(java.lang.Integer index);
  public io.fabric8.kubernetes.api.model.LabelSelectorRequirement buildFirstMatchExpression();
  public io.fabric8.kubernetes.api.model.LabelSelectorRequirement buildLastMatchExpression();
  public io.fabric8.kubernetes.api.model.LabelSelectorRequirement buildMatchingMatchExpression(java.util.function.Predicate<io.fabric8.kubernetes.api.model.LabelSelectorRequirementBuilder> predicate);
  public java.lang.Boolean hasMatchingMatchExpression(java.util.function.Predicate<io.fabric8.kubernetes.api.model.LabelSelectorRequirementBuilder> predicate);
  public A withMatchExpressions(java.util.List<io.fabric8.kubernetes.api.model.LabelSelectorRequirement> matchExpressions);
  public A withMatchExpressions(io.fabric8.kubernetes.api.model.LabelSelectorRequirement... matchExpressions);
  public java.lang.Boolean hasMatchExpressions();
  public io.fabric8.kubernetes.api.model.LabelSelectorFluent.MatchExpressionsNested<A> addNewMatchExpression();
  public io.fabric8.kubernetes.api.model.LabelSelectorFluent.MatchExpressionsNested<A> addNewMatchExpressionLike(io.fabric8.kubernetes.api.model.LabelSelectorRequirement item);
  public io.fabric8.kubernetes.api.model.LabelSelectorFluent.MatchExpressionsNested<A> setNewMatchExpressionLike(java.lang.Integer index,io.fabric8.kubernetes.api.model.LabelSelectorRequirement item);
  public io.fabric8.kubernetes.api.model.LabelSelectorFluent.MatchExpressionsNested<A> editMatchExpression(java.lang.Integer index);
  public io.fabric8.kubernetes.api.model.LabelSelectorFluent.MatchExpressionsNested<A> editFirstMatchExpression();
  public io.fabric8.kubernetes.api.model.LabelSelectorFluent.MatchExpressionsNested<A> editLastMatchExpression();
  public io.fabric8.kubernetes.api.model.LabelSelectorFluent.MatchExpressionsNested<A> editMatchingMatchExpression(java.util.function.Predicate<io.fabric8.kubernetes.api.model.LabelSelectorRequirementBuilder> predicate);
  public A addToMatchLabels(java.lang.String key,java.lang.String value);
  public A addToMatchLabels(java.util.Map<java.lang.String,java.lang.String> map);
  public A removeFromMatchLabels(java.lang.String key);
  public A removeFromMatchLabels(java.util.Map<java.lang.String,java.lang.String> map);
  public java.util.Map<java.lang.String,java.lang.String> getMatchLabels();
  public <K,V>A withMatchLabels(java.util.Map<java.lang.String,java.lang.String> matchLabels);
  public java.lang.Boolean hasMatchLabels();
  public interface MatchExpressionsNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.kubernetes.api.model.LabelSelectorRequirementFluent<io.fabric8.kubernetes.api.model.LabelSelectorFluent.MatchExpressionsNested<N>>{
    public N and();
    public N endMatchExpression();
    
  }
  
}

==> kubernetes-model-core-5.12.4-sources.jar: io/fabric8/kubernetes/api/model/LabelSelectorFluent.java <==
package io.fabric8.kubernetes.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import com.fasterxml.jackson.annotation.JsonInclude;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface LabelSelectorFluent<A extends io.fabric8.kubernetes.api.model.LabelSelectorFluent<A>> extends io.fabric8.kubernetes.api.builder.Fluent<A>{
  public A addToMatchExpressions(java.lang.Integer index,io.fabric8.kubernetes.api.model.LabelSelectorRequirement item);
  public A setToMatchExpressions(java.lang.Integer index,io.fabric8.kubernetes.api.model.LabelSelectorRequirement item);
  public A addToMatchExpressions(io.fabric8.kubernetes.api.model.LabelSelectorRequirement... items);
  public A addAllToMatchExpressions(java.util.Collection<io.fabric8.kubernetes.api.model.LabelSelectorRequirement> items);
  public A removeFromMatchExpressions(io.fabric8.kubernetes.api.model.LabelSelectorRequirement... items);
  public A removeAllFromMatchExpressions(java.util.Collection<io.fabric8.kubernetes.api.model.LabelSelectorRequirement> items);
  public A removeMatchingFromMatchExpressions(java.util.function.Predicate<io.fabric8.kubernetes.api.model.LabelSelectorRequirementBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildMatchExpressions instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public java.util.List<io.fabric8.kubernetes.api.model.LabelSelectorRequirement> getMatchExpressions();
  public java.util.List<io.fabric8.kubernetes.api.model.LabelSelectorRequirement> buildMatchExpressions();
  public io.fabric8.kubernetes.api.model.LabelSelectorRequirement buildMatchExpression(java.lang.Integer index);
  public io.fabric8.kubernetes.api.model.LabelSelectorRequirement buildFirstMatchExpression();
  public io.fabric8.kubernetes.api.model.LabelSelectorRequirement buildLastMatchExpression();
  public io.fabric8.kubernetes.api.model.LabelSelectorRequirement buildMatchingMatchExpression(java.util.function.Predicate<io.fabric8.kubernetes.api.model.LabelSelectorRequirementBuilder> predicate);
  public java.lang.Boolean hasMatchingMatchExpression(java.util.function.Predicate<io.fabric8.kubernetes.api.model.LabelSelectorRequirementBuilder> predicate);
  public A withMatchExpressions(java.util.List<io.fabric8.kubernetes.api.model.LabelSelectorRequirement> matchExpressions);
  public A withMatchExpressions(io.fabric8.kubernetes.api.model.LabelSelectorRequirement... matchExpressions);
  public java.lang.Boolean hasMatchExpressions();
  public io.fabric8.kubernetes.api.model.LabelSelectorFluent.MatchExpressionsNested<A> addNewMatchExpression();
  public io.fabric8.kubernetes.api.model.LabelSelectorFluent.MatchExpressionsNested<A> addNewMatchExpressionLike(io.fabric8.kubernetes.api.model.LabelSelectorRequirement item);
  public io.fabric8.kubernetes.api.model.LabelSelectorFluent.MatchExpressionsNested<A> setNewMatchExpressionLike(java.lang.Integer index,io.fabric8.kubernetes.api.model.LabelSelectorRequirement item);
  public io.fabric8.kubernetes.api.model.LabelSelectorFluent.MatchExpressionsNested<A> editMatchExpression(java.lang.Integer index);
  public io.fabric8.kubernetes.api.model.LabelSelectorFluent.MatchExpressionsNested<A> editFirstMatchExpression();
  public io.fabric8.kubernetes.api.model.LabelSelectorFluent.MatchExpressionsNested<A> editLastMatchExpression();
  public io.fabric8.kubernetes.api.model.LabelSelectorFluent.MatchExpressionsNested<A> editMatchingMatchExpression(java.util.function.Predicate<io.fabric8.kubernetes.api.model.LabelSelectorRequirementBuilder> predicate);
  public A addToMatchLabels(java.lang.String key,java.lang.String value);
  public A addToMatchLabels(java.util.Map<java.lang.String,java.lang.String> map);
  public A removeFromMatchLabels(java.lang.String key);
  public A removeFromMatchLabels(java.util.Map<java.lang.String,java.lang.String> map);
  public java.util.Map<java.lang.String,java.lang.String> getMatchLabels();
  public <K,V>A withMatchLabels(java.util.Map<java.lang.String,java.lang.String> matchLabels);
  public java.lang.Boolean hasMatchLabels();
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value);
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map);
  public A removeFromAdditionalProperties(java.lang.String key);
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map);
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties);
  public java.lang.Boolean hasAdditionalProperties();
  public interface MatchExpressionsNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.kubernetes.api.model.LabelSelectorRequirementFluent<io.fabric8.kubernetes.api.model.LabelSelectorFluent.MatchExpressionsNested<N>>{
    public N and();
    public N endMatchExpression();
    
  }
  
}
